==> cooptools-1.26-py3-none-any.whl: cooptools/geometry_utils/rect_utils.py <==
from typing import Tuple, Dict, Callable, Any
from cooptools.geometry_utils.vector_utils import bounded_by, distance_between
from cooptools.coopEnum import CardinalPosition
from functools import partial

Rect = Tuple[float, float, float, float] # x, y, w, h
RectComparer = Callable[[Rect, Any], bool]

def rect_corners(rect: Rect, cardinality: CardinalPosition = CardinalPosition.BOTTOM_LEFT) -> Dict[CardinalPosition, Tuple[float, float]]:
    x, y, w, h = rect

    if cardinality is None:
        cardinality = CardinalPosition.BOTTOM_LEFT

    partial_pos = partial(CardinalPosition.alignment_conversion,  dims=(w, h), anchor=(x, y), from_cardinality=cardinality)

    return {
        CardinalPosition.TOP_LEFT: partial_pos(to_cardinality=CardinalPosition.TOP_LEFT),
        CardinalPosition.TOP_RIGHT: partial_pos(to_cardinality=CardinalPosition.TOP_RIGHT),
        CardinalPosition.BOTTOM_RIGHT: partial_pos(to_cardinality=CardinalPosition.BOTTOM_RIGHT),
        CardinalPosition.BOTTOM_LEFT: partial_pos(to_cardinality=CardinalPosition.BOTTOM_LEFT)
    }

def rect_center(rect: Rect) -> Tuple[float, float]:
    x, y, w, h = rect
    return CardinalPosition.alignment_from_bottom_left(dims=(w, h),
                                                    bottom_left=(x, y),
                                                    cardinality=CardinalPosition.CENTER)

def rect_contains_point(rect: Rect, pt: Tuple[float, float]) -> bool:
    x, y, w, h = rect
    return bounded_by(pt, (x, y), (x + w, y + h))

def overlaps(rect1: Tuple[float, float, float, float],
             rect2: Tuple[float, float, float, float]) -> bool:

    r1_corners = rect_corners(rect1)
    r2_corners = rect_corners(rect2)

    return any(rect_contains_point(rect1, pt) for card, pt in r2_corners.items()) or \
           any(rect_contains_point(rect2, pt) for card, pt in r1_corners.items())

def bounding_circle_radius(rect: Rect) -> float:
    x, y, w, h = rect
    center = CardinalPosition.alignment_from_bottom_left(dims=(w, h),
                                                    bottom_left=(x, y),
                                                    cardinality=CardinalPosition.CENTER)

    return distance_between((x, y), center)

if __name__ == "__main__":
    from pprint import pprint
    rect = 10, 10, 50, 100
    pprint(rect_corners(rect))

==> cooptools-1.37-py3-none-any.whl: cooptools/geometry_utils/rect_utils.py <==
from typing import Tuple, Dict, Callable, Any
from cooptools.geometry_utils.vector_utils import bounded_by, distance_between
from cooptools.coopEnum import CardinalPosition
from functools import partial
from cooptools.geometry_utils import polygon_utils as poly
import random as rnd

Rect = Tuple[float, float, float, float] # x, y, w, h
RectComparer = Callable[[Rect, Any], bool]

def rect_corners(rect: Rect, cardinality: CardinalPosition = CardinalPosition.BOTTOM_LEFT) -> Dict[CardinalPosition, Tuple[float, float]]:
    x, y, w, h = rect

    if cardinality is None:
        cardinality = CardinalPosition.BOTTOM_LEFT

    partial_pos = partial(CardinalPosition.alignment_conversion,  dims=(w, h), anchor=(x, y), from_cardinality=cardinality)

    return {
        CardinalPosition.TOP_LEFT: partial_pos(to_cardinality=CardinalPosition.TOP_LEFT),
        CardinalPosition.TOP_RIGHT: partial_pos(to_cardinality=CardinalPosition.TOP_RIGHT),
        CardinalPosition.BOTTOM_RIGHT: partial_pos(to_cardinality=CardinalPosition.BOTTOM_RIGHT),
        CardinalPosition.BOTTOM_LEFT: partial_pos(to_cardinality=CardinalPosition.BOTTOM_LEFT)
    }

def rect_center(rect: Rect) -> Tuple[float, float]:
    x, y, w, h = rect
    return CardinalPosition.alignment_from_bottom_left(dims=(w, h),
                                                    bottom_left=(x, y),
                                                    cardinality=CardinalPosition.CENTER)

def rect_contains_point(rect: Rect, pt: Tuple[float, float]) -> bool:
    x, y, w, h = rect
    return bounded_by(pt, (x, y), (x + w, y + h))

def unrotated_overlaps(rect1: Tuple[float, float, float, float],
                       rect2: Tuple[float, float, float, float]) -> bool:

    r1_corners = rect_corners(rect1)
    r2_corners = rect_corners(rect2)

    return any(rect_contains_point(rect1, pt) for card, pt in r2_corners.items()) or \
           any(rect_contains_point(rect2, pt) for card, pt in r1_corners.items())

def bounding_circle_radius(rect: Rect) -> float:
    x, y, w, h = rect
    center = CardinalPosition.alignment_from_bottom_left(dims=(w, h),
                                                    bottom_left=(x, y),
                                                    cardinality=CardinalPosition.CENTER)

    return distance_between((x, y), center)

def rect_gen(_rect, max_w = None, max_h = None):
    x = rnd.uniform(_rect[0], _rect[0] + _rect[2] - 1)
    y = rnd.uniform(_rect[1], _rect[1] + _rect[3] - 1)
    w = min(rnd.uniform(x, _rect[2] - 1), max_w if max_w else 100000000000000)
    h = min(rnd.uniform(y, _rect[3] - 1), max_h if max_h else 100000000000000)

    return x, y, w, h

if __name__ == "__main__":
    from pprint import pprint
    rect = 10, 10, 50, 100
    pprint(rect_corners(rect))
